﻿using MindFusion.Diagramming.Wpf;
using System.Diagnostics;
using System.Numerics;
using System.Windows;
using System.Windows.Media;

namespace MindfusionNewVersionIssues
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();

            var diagram = DiagramView.Diagram;


            DiagramView.ZoomFactor = 100;

            DiagramView.Diagram = diagram;
            DiagramView.MiddleButtonActions = MouseButtonActions.Pan;
            var random = new Random();

            DiagramView.CustomBehavior = new MindfusionMoveNodesBehavior(DiagramView);

            var imageNode = new SvgNode()
            {
                Transparent = true,
            };
            imageNode.Image = ImageUtils.CreateImage(".\\images\\controller.png");

            diagram.Nodes.Add(imageNode);
            diagram.Nodes.Last().Move(100, 200);

            var matrixTransform = new MatrixTransform();
            var trs = CreateTRSMatrix(Vector2.Zero, 180, new Vector2(2));
            matrixTransform.Matrix = new Matrix(trs.M11, trs.M12, trs.M21, trs.M22, trs.M31, trs.M32);

            imageNode.RenderTransform = matrixTransform;
        }

        public static Matrix3x2 CreateTRSMatrix(Vector2 position, float rotation, Vector2 scale)
        {
            float cos = MathF.Cos(rotation);
            float sin = MathF.Sin(rotation);

            Debug.Assert(scale.X != 0 && scale.Y != 0, "Incorrect scale matrix.");

            return new Matrix3x2(
                cos * scale.X,
                sin * scale.X,
                -sin * scale.Y,
                cos * scale.Y,
                position.X,
                position.Y);
        }
    }
}